from setuptools import setup
setup(name="promptstudio", version="0.0.1", py_modules=["promptstudio"], author="me", author_email="me@me.com", description="This is a placeholder package created by registerit.", url="http://www.github.com")